@@ -1,7 +1,8 @@
+#include <R.h>
+#include <Rmath.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 ///// declarations
